@@ -18,6 +18,10 @@
 #ifndef GENERICSCANNER_H
 #define GENERICSCANNER_H
 
+#include "sockethandler.h"
+#include "logfile.h"
+
+
 #include <sys/types.h>
 
 #include <iostream>
@@ -38,12 +42,13 @@ pid_t ScannerPid;
 
 public:
 
+int msgqid;
+
 void WriteScannerAnswer ();
 
 string ReadScannerAnswer ();
 
-bool PrepareScanning ( void *GenericScannerT );
-
+bool PrepareScanning ( SocketHandler *ProxyServerT );
 
 virtual bool InitDatabase() = 0;
 
@@ -59,6 +64,8 @@ virtual bool SetFileSize( unsigned long ContentLengthT ) = 0;
 
 virtual bool ExpandFile( char *dataT, int lengthT , bool unlockT) = 0 ;
 
+virtual bool DeleteFile() = 0;
+
 virtual ~GenericScanner ();
 
 GenericScanner ();
