@@ -25,6 +25,7 @@
 
 #include <iostream>
 #include <string>
+#include <deque>
 
 using namespace std;
 
@@ -35,19 +36,21 @@ private:
 
 bool HeaderSend;
 
-//string Host;
-//int Port;
+bool BrowserDropped;
 
 ConnectionToBrowser ToBrowser;
 ConnectionToServer ToServer;
 
+//PSEstart
+//bool ProxyMessage( int CommunicationAnswerT );
 bool ProxyMessage( int CommunicationAnswerT, GenericScanner *VirusScannerT );
+//PSEend
 
-int Communication( SocketHandler *ProxyServerT, GenericScanner *VirusScannerT);
+int Communication( SocketHandler *ProxyServerT, GenericScanner *VirusScannerT );
  
 public:
 
- bool Proxy ( SocketHandler *ProxyServerT, GenericScanner *VirusScannerT);
+ bool Proxy ( SocketHandler *ProxyServerT, GenericScanner *VirusScannerT );
  
  
 	ProxyHandler();
